%define name    autofs
%define version 5.0.1
%define beta    rc2
%define release %mkrel 0.%{beta}.2

Name:           %{name}
Version:        %{version}
Release:        %{release}
License:        GPL
Summary:        A tool for automatically mounting and unmounting filesystems
Group:          System/Kernel and hardware
URL:            ftp://ftp.kernel.org/pub/linux/daemons/autofs
Source0:        ftp://ftp.kernel.org/pub/linux/daemons/autofs/v5/autofs-%{version}-%{beta}.tar.bz2
Source1:        %{name}.init
Patch100:       autofs-5.0.1-rc1-fix-man-page.patch
Patch101:       autofs-5.0.1-rc1-drop-default-prefix-from-config.patch
Patch102:       autofs-5.0.1-rc1-separate-config-files.patch
Patch103:       autofs-5.0.1-rc1-cleanup-config-files-names.patch
Patch104:       autofs-5.0.1-rc1-fix-ldap-lookup.patch
Patch105:       autofs-5.0.1-rc1-comment-default-master-map.patch
Patch200:       autofs-5.0.1-rc1-fix-hesiod-check.patch
Requires:       nfs-utils-clients
Requires:       kernel >= 2.6.17
Requires(post): rpm-helper
Requires(preun):rpm-helper
BuildRequires:  openldap-devel
BuildRequires:  flex
BuildRequires:  bison
Conflicts:      autosmb
Buildroot:      %{_tmppath}/%{name}-%{version}

%description
autofs is a daemon which automatically mounts filesystems when you use
them, and unmounts them later when you are not using them.  This can
include network filesystems, CD-ROMs, floppies, and so forth.

%prep
%setup -q -n %{name}-%{version}
%patch100 -p 1
%patch101 -p 1
%patch102 -p 1
%patch103 -p 1
%patch104 -p 1
%patch105 -p 1
%patch200 -p 1

%build
autoconf-2.5x
%serverbuild
%configure --with-mapdir=%{_sysconfdir}/%{name} \
           --with-confdir=%{_sysconfdir}/%{name} \
           --with-sasl=no
%make DONTSTRIP=1

mkdir examples
cp samples/ldap* examples
cp samples/autofs.schema examples

rm -f README.gentoo

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_libdir}/autofs
mkdir -p %{buildroot}%{_mandir}/{man5,man8}
mkdir -p %{buildroot}%{_sysconfdir}

%make install INSTALLROOT=%{buildroot}

install -d -m 755 %{buildroot}%{_initrddir}
install -m 755 %{SOURCE1} %{buildroot}%{_initrddir}/%{name}

rm -f %{buildroot}%{_sysconfdir}/init.d/%{name}

cat > README.urpmi <<EOF
Mandriva RPM specific notes

setup
-----
The configuration files setup differs from default one, by separating daemon
configuration file (%{_sysconfdir}/autofs/autofs.conf) from initscript
configuration file (%{_sysconfdir}/sysconfig/autofs).

Upgrade
-------
Map files have been moved from %{_sysconfdir} to %{_sysconfdir}/autofs. Upgrade
procedure should handle the change automatically.
LDAP usage has changed between autofs 4 and 5. The LDAP schema used has now to
be configured explicitely in autofs configuration, so as to avoid useless
queries. As this can't be handled by package upgrade procedure, you'll have to
edit your configuration manually. See auto.master(5) for details.

EOF

%pre
if [ $1 = "0" ]; then
    # installation
    if grep -q '^alias autofs autofs4'  /etc/modules.conf; then
    echo "alias autofs autofs4" >> /etc/modules.conf
    fi
else
    if [ ! -d %{_sysconfdir}/autofs ]; then
        # 4 -> 5 upgrade
        mkdir %{_sysconfdir}/autofs
        for file in %{_sysconfdir}/auto.{master,misc,net,smb}; do
            if [ -f "$file" ]; then
                mv $file* %{_sysconfdir}/autofs
            fi
        done
    fi
fi

%post
%_post_service autofs

%preun
%_preun_service autofs

%postun
if [ $1 = "0" ]; then # removal
    perl -ni -e 'print unless ( m!^.*autofs.*$! || /^\s*$/)' /etc/modules.conf
fi

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc INSTALL CHANGELOG CREDITS README* examples
%config(noreplace) %{_sysconfdir}/autofs
%config(noreplace) %{_sysconfdir}/sysconfig/autofs
%{_initrddir}/%{name}
%{_libdir}/%{name}
%{_sbindir}/automount
%{_mandir}/*/*

%changelog
* Tue Sep 12 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc2.2mdv2007.0
- more dependencies in init script

* Mon Sep 04 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc2.1mdv2007.0
- new version
- fix reload function in initscript (#25128)
- changed README.mdv to README.urpmi
- add some notes about LDAP handling change

* Fri Sep 01 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.6mdv2007.0
- comment default master map entries
- soft dependencies against ldap in init script

* Mon Aug 28 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.5mdv2007.0
- buildrequires

* Mon Aug 28 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.4mdv2007.0
- more cautious file testing during upgrade (fix #24768)

* Fri Aug 25 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.3mdv2007.0
- fix ldap lookup when only a map name is given

* Fri Aug 25 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.2mdv2007.0
- fix prevention of stripping

* Thu Aug 24 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.1-0.rc1.1mdv2007.0
- new version
- handle 4.x -> 5.x configuration file location change
- add status option to init script

* Thu Jun 29 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.0.0-0.beta6.1mdv2007.0
- new version
- move configuration files in %{_sysconfdir}/autofs
- drop patches 1 and 9 (merged upstream)
- drop patch 2, 3, 7 and 12 (useless or undesirable according to developpers)
- use -DDONTSTRIP instead of -DDEBUG to prevent stripping before installation

* Fri Apr 28 2006 Stefan van der Eijk <stefan@eijk.nu> 4.1.4-9mdk
- Rebuild for sparc

* Thu Jan 26 2006 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.4-8mdk
- multimount patch (Andrey Borzenkov <arvidjaar@mail.ru>)
- various fixes in init script (Quel Qun <kelk1@comcast.net>)
- more init script cleanup

* Thu Jan 19 2006 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.4-6mdk
- new custom initscript, with parallel init and timeout support
- move executable scripts from %{_sysconfdir} to %{_libdir}/%{name}
- drop redundant portmap requires
- drop useless README files

* Mon Nov 14 2005 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.4-5mdk
- define -DLDAP_DEPRECATED (fix #19605)
- make sure -g and standard optimisation flags are used
- cleanup samples file in documentation
- don't mark scripts as executable (TODO: install them under %{_libdir}/%{name})
- drop non-applied patches

* Fri Nov 04 2005 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.4-4mdk
- spec cleanup
- more macros

* Tue Aug 30 2005 Oden Eriksson <oeriksson@mandriva.com> 4.1.4-3mdk
- rebuilt against new openldap-2.3.6 libs
- misc rpmlint fixes

* Wed Jul 13 2005 Nicolas Lcureuil <neoclust@mandriva.org> 4.1.4-2mdk
- Fix conflicts
- preReq => Requires(pre)

* Sun May 22 2005 Stefan van der Eijk <stefan@eijk.nu> 4.1.4-1mdk
- 4.1.4
- start autofs after named (45 --> 60)
- rediffed patch 3 (auto-master)
- rediffed patch 4 (init-redhat-only) now only changes the runlevel config
- rediffed patch 8 (stripdash)
- remove patch 20 (bad_chdir) merged upstream
- remove patch 21 (mtab_lock) merged upstream
- remove patch 22 (non_block_ping) merged upstream
- disable patch 23 (replicated_server_select) more or less merged upstream
- rediffed patch 24 (signal-race-fix)
- disable patch 25 (sock-leak-fix) more or less merged upstream
- remove patch 26 (strict) merged upstream
- spec file cosmetics (%%mkrel, remove %%ver, no TODO file in doc, add auto.smb)
 
* Fri Feb 04 2005 Buchan Milne <bgmilne@linux-mandrake.com> 4.1.3-3mdk
- rebuild for ldap2.2_7

* Tue Nov 23 2004 Stefan van der Eijk <stefan@mandrake.org> 4.1.3-2mdk
- let autofs start after the ldap server

* Tue Nov 23 2004 Stefan van der Eijk <stefan@mandrake.org> 4.1.3-1mdk
- 4.1.3
- rediff patch 4
- add 4.1.3 patches

* Tue May  4 2004 Juan Quintela <quintela@mandrakesoft.com> 4.1.2-1mdk
- merge with redhat 4.1.2-2.
- actualize spec file.
- lots of patches included upstream or irrelevant.
- 4.1.2.

* Tue Apr 06 2004 Stefan van der Eijk <stefan@eijk.nu> 4.0.0-0.22mdk
- Patch18: ldapv3 patch from mc@suse.de
- Source1: replace with suse's ldapv3 enabled one
- from Michael Scherer : clean some requires

* Fri Nov 14 2003 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 4.0.0-0.21mdk
- 64-bit fixes

* Fri Oct 31 2003 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 4.0.0-0.20mdk
- lib64 fixes

* Tue Jul 22 2003 Per yvind Karlsen <peroyvind@sintrax.net> 4.0.0-0.19mdk
- rebuild
- drop prefix tag
- drop unapplied P11

* Thu Nov 07 2002 Thierry Vignaud <tvignaud@mandrakesoft.com> 4.0.0-0.18mdk
- requires s/(sh-|text)utils/coreutils/
- PreReq: rpm-helper

* Tue Feb 26 2002 Thierry Vignaud <tvignaud@mandrakesoft.com> 4.0.0-0.17mdk
- init script: s/grpintf/gprintf/g (garrick)

* Fri Nov 30 2001 Frederic Lepied <flepied@mandrakesoft.com> 4.0.0-0.16mdk
- gprintfy the init script by hand because a lot of echo must not be
gprintified.

* Thu Oct 18 2001 Philippe Libat <philippe@mandrakesoft.com> 4.0.0-0.15mdk
- add multiargs, fpic, schema patch.
- add autofs-ldap-auto-master
- new autofs.init script: determine nis & ldap lookup from nsswitch.conf

* Thu Sep 13 2001 Philippe Libat <philippe@mandrakesoft.com> 4.0.0-0.14mdk
- added nfs-utils-clients require 

* Thu Jul  5 2001 Frederic Lepied <flepied@mandrakesoft.com> 4.0.0-0.13mdk
- rebuild for new db3.2

* Mon Jul 02 2001 Philippe Libat <philippe@mandrakesoft.com> 4.0.0-0.12mdk
- auto.net patch

* Thu Jun 19 2001 Philippe Libat <philippe@mandrakesoft.com> 4.0.0-0.11mdk
- fix reload/restart init (Sebastian Dransfeld <sebastid@stud.ntnu.no>)

* Thu Jun 19 2001 Philippe Libat <philippe@mandrakesoft.com> 4.0.0-0.10mdk
- ldap initrd

* Mon Jun 11 2001 Vincent Saugey <vince@mandrakesoft.com> 4.0.0-0.9mdk
- rebuild with ldap2 lib

* Tue Apr 10 2001 Renaud Chaillat <rchaillat@mandrakesoft.com> 4.0.0-0.8mdk
- new version (pre10)

* Thu Mar 29 2001 Frederic Lepied <flepied@mandrakesoft.com> 4.0.0-0.7mdk
- use the new rpm macros for servers.

* Mon Mar 26 2001 Frederic Lepied <flepied@mandrakesoft.com> 4.0.0-0.6mdk
- removed /misc and /net

* Mon Nov  6 2000 Renaud Chaillat <rchaillat@mandrakesoft.com> 4.0.0-0.5mdk
- new version
- updated patches and init script

* Tue Sep  5 2000 Frederic Lepied <flepied@mandrakesoft.com> 4.0.0-0.4mdk
- use condrestart on upgrade.
- enabled again init patch to have a condrestart and to have a start at 18 level.

* Wed Aug 30 2000 Geoffrey Lee <snailtalk@mandrakesoft.com> 4.0.0-0.3mdk
- rebuild for the user of _initrddir macro.

* Fri Aug 18 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 4.0.0-0.2mdk
- rebuild to get rid of "if your Red Hat Linux machine is.."
  thanks to Anton Graham <darkimage@bigfoot.com>

* Thu Aug 17 2000 Frederic Lepied <flepied@mandrakesoft.com> 4.0.0-0.1mdk
- 4.0.0pre7

* Thu Jul 20 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 3.1.5-1mdk
- 3.1.5
- BM
- macroqeivhqowicvjzificationning

* Fri Apr 28 2000 Warly <warly@mandrakesoft.com> 3.1.4-4mdk
- change rc.init value to S72 K08
 
* Tue Mar 22 2000 Daouda Lo <daouda@mandrakesoft.com> 3.1.4-3mdk
- fix wrong date.
- 3.1.4 (new release).
- remove ugly patches.
- add smbmount support.

* Tue Nov 23 1999 Axalon Bloodstone <axalon@linux-mandrake.com>
- strip

* Sun Oct 31 1999 Axalon Bloodstone <axalon@linux-mandrake.com>
- Enable $SMP build/check

* Wed Oct  6 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- checkconfig --del in %preun, not %postun (rh).
- add patch from HJLu to handle NIS auto.master better (rh).

* Fri Sep 24 1999 Axalon Bloodstone <axalon@linux-mandrake.com>
- Forgot to fix the bloody permissions :/

* Fri Sep 24 1999 Axalon Bloodstone <axalon@linux-mandrake.com>
- remove rc patch it's breaking yp
- again with the redhat mergeings:
    * Wed Aug 25 16:00:00 1999 Cristian Gafton <gafton@redhat.com>
    - fix bug #4708
    * Sat Aug 21 16:00:00 1999 Bill Nottingham <notting@redhat.com>
    - fix perms on /usr/lib/autofs/*
    - add support for specifying maptype in auto.master

* Tue Aug 17 1999 Axalon Bloodstone <axalon@linux-mandrake.com>
- RedHat Merge:
    * Fri Aug 13 1999 Cristian Gafton <gafton@redhat.com>
    - add patch from rth to avoid an infinite loop

* Wed Jun 23 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>

- Patch from H.J Lu <hjl@varesearch.com> :
    -* fix rc script for /var/lock/subsys.

* Tue May 11 1999 Bernhard Rosenkraenzer <bero@mandrakesoft.com>
- Mandrake adaptions
